@@ -64,12 +64,11 @@
 get_voteview_members <- function(chamber = "all", congress = NULL, local_path = NULL) {
   # join multiple congresses (for online downloads)
   if (length(congress) > 1 && is.numeric(congress) && is.null(local_path)) {
-    list_of_dfs <- lapply(congress, function(.cong) {
-      get_voteview_members(chamber = chamber,
-                           congress = .cong,
-                           local_path = local_path)
-    })
-    return(dplyr::bind_rows(list_of_dfs))
+    return(
+      multi_congress_read(fun = get_voteview_members,
+                          chamber = chamber,
+                          congress = congress)
+    )
   }
 
   if (is.null(local_path)) {
